Account class abstract

Available extensions
Annotations
  • @freezed

Constructors

Account({required String id, required String providerId, required String accountId, required String userId, String? accessToken, String? refreshToken, String? idToken, DateTime? accessTokenExpiresAt, DateTime? refreshTokenExpiresAt, String? scope, String? password, @Default.new(null) DateTime? createdAt, @Default.new(null) DateTime? updatedAt})
const
factory
Account.fromJson(Map<String, dynamic> json)
factory

Properties

accessToken String?
no setterinherited
accessTokenExpiresAt DateTime?
no setterinherited
accountId String
no setterinherited
copyWith → $AccountCopyWith<Account>
Create a copy of Account with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
idToken String?
no setterinherited
password String?
no setterinherited
providerId String
no setterinherited
refreshToken String?
no setterinherited
refreshTokenExpiresAt DateTime?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
no setterinherited
updatedAt DateTime?
no setterinherited
userId String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Account value)) → TResult

Available on Account, provided by the AccountPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Account value)?) → TResult?

Available on Account, provided by the AccountPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Account value)?, {required TResult orElse()}) → TResult

Available on Account, provided by the AccountPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String providerId, String accountId, String userId, String? accessToken, String? refreshToken, String? idToken, DateTime? accessTokenExpiresAt, DateTime? refreshTokenExpiresAt, String? scope, String? password, DateTime? createdAt, DateTime? updatedAt)?, {required TResult orElse()}) → TResult

Available on Account, provided by the AccountPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Account to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String providerId, String accountId, String userId, String? accessToken, String? refreshToken, String? idToken, DateTime? accessTokenExpiresAt, DateTime? refreshTokenExpiresAt, String? scope, String? password, DateTime? createdAt, DateTime? updatedAt)) → TResult

Available on Account, provided by the AccountPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String providerId, String accountId, String userId, String? accessToken, String? refreshToken, String? idToken, DateTime? accessTokenExpiresAt, DateTime? refreshTokenExpiresAt, String? scope, String? password, DateTime? createdAt, DateTime? updatedAt)?) → TResult?

Available on Account, provided by the AccountPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited