Session class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
Session({required String id, required String token, required DateTime expiresAt, DateTime? createdAt, DateTime? updatedAt, String? ipAddress, String? userAgent, required String userId, String? impersonatedBy, String? activeOrganizationId, String? activeTeamId, @JsonKey.new(readValue: _readSessionAdditionalFields, includeToJson: false) @Default.new(<String, dynamic>{}) Map<
String, dynamic> additionalFields}) -
constfactory
-
Session.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeOrganizationId → String?
-
no setterinherited
- activeTeamId → String?
-
Present when Better Auth
organizationis configured withteams.enabled.no setterinherited -
additionalFields
→ Map<
String, dynamic> -
Server-defined custom fields (
additionalFields) that aren't part of the static Session shape. Populated from unmapped JSON keys by Session.fromJson; never serialized back out. Read via thefieldextension, e.g.session.field<String>('theme').no setterinherited -
copyWith
→ $SessionCopyWith<
Session> -
Create a copy of Session
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
no setterinherited
- expiresAt → DateTime
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- impersonatedBy → String?
-
no setterinherited
- ipAddress → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
no setterinherited
- updatedAt → DateTime?
-
no setterinherited
- userAgent → String?
-
no setterinherited
- userId → String
-
no setterinherited
Methods
-
field<
T> (String key, {T decode(Object? value)?}) → T? -
Available on Session, provided by the SessionAdditionalFields extension
ReadskeyfromSession.additionalFields, casting toT. -
map<
TResult extends Object?> (TResult $default(_Session value)) → TResult -
Available on Session, provided by the SessionPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Session value)?) → TResult? -
Available on Session, provided by the SessionPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Session value)?, {required TResult orElse()}) → TResult -
Available on Session, provided by the SessionPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String token, DateTime expiresAt, DateTime? createdAt, DateTime? updatedAt, String? ipAddress, String? userAgent, String userId, String? impersonatedBy, String? activeOrganizationId, String? activeTeamId, Map< String, dynamic> additionalFields)?, {required TResult orElse()}) → TResult -
Available on Session, provided by the SessionPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Session to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String token, DateTime expiresAt, DateTime? createdAt, DateTime? updatedAt, String? ipAddress, String? userAgent, String userId, String? impersonatedBy, String? activeOrganizationId, String? activeTeamId, Map< String, dynamic> additionalFields)) → TResult -
Available on Session, provided by the SessionPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String token, DateTime expiresAt, DateTime? createdAt, DateTime? updatedAt, String? ipAddress, String? userAgent, String userId, String? impersonatedBy, String? activeOrganizationId, String? activeTeamId, Map< String, dynamic> additionalFields)?) → TResult? -
Available on Session, provided by the SessionPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited