ApiKeyBetterAuth class abstract

Annotations
  • @RestApi.new(callAdapter: BetterAuthCallAdapter)

Constructors

ApiKeyBetterAuth(Dio dio, {String? baseUrl, ParseErrorLogger? errorLogger})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({String? configId, String? name, int? expiresIn, String? userId, String? organizationId, String? prefix, int? remaining, Map<String, dynamic>? metadata, Map<String, dynamic>? permissions}) Future<Result<ApiKeyModel>>
delete({String? configId, required String keyId}) Future<Result<SuccessResponse>>
deleteAllExpired({Map<String, dynamic> body = const {}}) Future<Result<DeleteExpiredApiKeysResponse>>
fetch({String? configId, required String id}) Future<Result<ApiKeyModel>>
Same as Better Auth client authClient.apiKey.get (GET /api-key/get).
list({String? configId, String? organizationId, int? limit, int? offset, String? sortBy, String? sortDirection}) Future<Result<ApiKeysListResponse>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update({String? configId, required String keyId, String? userId, String? name, bool? enabled, int? remaining, int? refillAmount, int? refillInterval, Map<String, dynamic>? metadata}) Future<Result<ApiKeyModel>>
verify({String? configId, required String key, Map<String, dynamic>? permissions}) Future<Result<VerifyApiKeyResponse>>

Operators

operator ==(Object other) bool
The equality operator.
inherited