toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'ApiKeyModel(id: $id, configId: $configId, name: $name, start: $start, prefix: $prefix, key: $key, referenceId: $referenceId, refillInterval: $refillInterval, refillAmount: $refillAmount, lastRefillAt: $lastRefillAt, enabled: $enabled, rateLimitEnabled: $rateLimitEnabled, rateLimitTimeWindow: $rateLimitTimeWindow, rateLimitMax: $rateLimitMax, requestCount: $requestCount, remaining: $remaining, lastRequest: $lastRequest, expiresAt: $expiresAt, createdAt: $createdAt, updatedAt: $updatedAt, metadata: $metadata, permissions: $permissions)';
}