InvitationWithMemberResponse class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- InvitationWithMemberResponse({required OrganizationInvitation invitation, OrganizationMember? member})
-
constfactory
-
InvitationWithMemberResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $InvitationWithMemberResponseCopyWith<
InvitationWithMemberResponse> -
Create a copy of InvitationWithMemberResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- invitation → OrganizationInvitation
-
no setterinherited
- member → OrganizationMember?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_InvitationWithMemberResponse value)) → TResult -
Available on InvitationWithMemberResponse, provided by the InvitationWithMemberResponsePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_InvitationWithMemberResponse value)?) → TResult? -
Available on InvitationWithMemberResponse, provided by the InvitationWithMemberResponsePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_InvitationWithMemberResponse value)?, {required TResult orElse()}) → TResult -
Available on InvitationWithMemberResponse, provided by the InvitationWithMemberResponsePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(OrganizationInvitation invitation, OrganizationMember? member)?, {required TResult orElse()}) → TResult -
Available on InvitationWithMemberResponse, provided by the InvitationWithMemberResponsePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this InvitationWithMemberResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(OrganizationInvitation invitation, OrganizationMember? member)) → TResult -
Available on InvitationWithMemberResponse, provided by the InvitationWithMemberResponsePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(OrganizationInvitation invitation, OrganizationMember? member)?) → TResult? -
Available on InvitationWithMemberResponse, provided by the InvitationWithMemberResponsePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited