OrganizationInvitation class abstract

Available extensions
Annotations
  • @freezed

Constructors

OrganizationInvitation({required String id, required String email, String? role, required String organizationId, required String inviterId, required String status, DateTime? expiresAt, DateTime? createdAt, String? organizationName, String? organizationSlug, String? inviterEmail, List<String>? teamIds})
const
factory
OrganizationInvitation.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $OrganizationInvitationCopyWith<OrganizationInvitation>
Create a copy of OrganizationInvitation with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime?
no setterinherited
email String
no setterinherited
expiresAt DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
inviterEmail String?
no setterinherited
inviterId String
no setterinherited
organizationId String
no setterinherited
organizationName String?
no setterinherited
organizationSlug String?
no setterinherited
role String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
no setterinherited
teamIds List<String>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_OrganizationInvitation value)) → TResult

Available on OrganizationInvitation, provided by the OrganizationInvitationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_OrganizationInvitation value)?) → TResult?

Available on OrganizationInvitation, provided by the OrganizationInvitationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_OrganizationInvitation value)?, {required TResult orElse()}) → TResult

Available on OrganizationInvitation, provided by the OrganizationInvitationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String email, String? role, String organizationId, String inviterId, String status, DateTime? expiresAt, DateTime? createdAt, String? organizationName, String? organizationSlug, String? inviterEmail, List<String>? teamIds)?, {required TResult orElse()}) → TResult

Available on OrganizationInvitation, provided by the OrganizationInvitationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this OrganizationInvitation to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String email, String? role, String organizationId, String inviterId, String status, DateTime? expiresAt, DateTime? createdAt, String? organizationName, String? organizationSlug, String? inviterEmail, List<String>? teamIds)) → TResult

Available on OrganizationInvitation, provided by the OrganizationInvitationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String email, String? role, String organizationId, String inviterId, String status, DateTime? expiresAt, DateTime? createdAt, String? organizationName, String? organizationSlug, String? inviterEmail, List<String>? teamIds)?) → TResult?

Available on OrganizationInvitation, provided by the OrganizationInvitationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited