OrganizationMember class abstract

Available extensions
Annotations
  • @freezed

Constructors

OrganizationMember({required String id, required String organizationId, required String userId, required String role, DateTime? createdAt, User? user})
const
factory
OrganizationMember.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $OrganizationMemberCopyWith<OrganizationMember>
Create a copy of OrganizationMember with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
organizationId String
no setterinherited
role String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user User?
no setterinherited
userId String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_OrganizationMember value)) → TResult

Available on OrganizationMember, provided by the OrganizationMemberPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_OrganizationMember value)?) → TResult?

Available on OrganizationMember, provided by the OrganizationMemberPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_OrganizationMember value)?, {required TResult orElse()}) → TResult

Available on OrganizationMember, provided by the OrganizationMemberPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String organizationId, String userId, String role, DateTime? createdAt, User? user)?, {required TResult orElse()}) → TResult

Available on OrganizationMember, provided by the OrganizationMemberPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this OrganizationMember to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String organizationId, String userId, String role, DateTime? createdAt, User? user)) → TResult

Available on OrganizationMember, provided by the OrganizationMemberPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String organizationId, String userId, String role, DateTime? createdAt, User? user)?) → TResult?

Available on OrganizationMember, provided by the OrganizationMemberPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited