PasskeyUpdateResponse class abstract

Response shape for POST /passkey/update-passkey.

Available extensions
Annotations
  • @freezed

Constructors

PasskeyUpdateResponse({required PasskeyRecord passkey})
const
factory
PasskeyUpdateResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PasskeyUpdateResponseCopyWith<PasskeyUpdateResponse>
Create a copy of PasskeyUpdateResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
passkey PasskeyRecord
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PasskeyUpdateResponse value)) → TResult

Available on PasskeyUpdateResponse, provided by the PasskeyUpdateResponsePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PasskeyUpdateResponse value)?) → TResult?

Available on PasskeyUpdateResponse, provided by the PasskeyUpdateResponsePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PasskeyUpdateResponse value)?, {required TResult orElse()}) → TResult

Available on PasskeyUpdateResponse, provided by the PasskeyUpdateResponsePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(PasskeyRecord passkey)?, {required TResult orElse()}) → TResult

Available on PasskeyUpdateResponse, provided by the PasskeyUpdateResponsePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PasskeyUpdateResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(PasskeyRecord passkey)) → TResult

Available on PasskeyUpdateResponse, provided by the PasskeyUpdateResponsePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(PasskeyRecord passkey)?) → TResult?

Available on PasskeyUpdateResponse, provided by the PasskeyUpdateResponsePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited