FlutterBetterAuth class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appScheme ↔ String?
-
getter/setter pair
- baseUrl ↔ String
-
getter/setter pair
- bearerToken → String?
-
Current bearer token, if the server's
bearerplugin issued one.no setter - client → BetterAuthClient
-
no setter
-
getter/setter pair
- dioClient ↔ Dio
-
getter/setter pair
- storage ↔ StorageInterface?
-
getter/setter pair
Static Methods
-
initialize(
{required String url, Dio? dio, StorageInterface? store, String? scheme, bool refreshSessionOnAppResume = true, bool refreshSessionOnReconnect = true}) → Future< void> -
refreshSession(
) → Future< void> -
reset(
) → void -
setBearerToken(
String? token) → void - Persists a new bearer token (called by the interceptor).