AnonymousBetterAuth class abstract
Better Auth anonymous
plugin: delete anonymous account.
Anonymous sign-in uses client.signIn.anonymous() (POST /sign-in/anonymous).
- Annotations
-
- @RestApi.new(callAdapter: BetterAuthCallAdapter)
Constructors
- AnonymousBetterAuth(Dio dio, {String? baseUrl, ParseErrorLogger? errorLogger})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteAnonymousUser(
{Map< String, dynamic> body = const {}}) → Future<Result< SuccessResponse> > - Requires session; rejects non-anonymous users. Clears session on success.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited