MagicLinkBetterAuth class abstract
Better Auth magic-link plugin.
- Annotations
-
- @RestApi.new(callAdapter: BetterAuthCallAdapter)
Constructors
- MagicLinkBetterAuth(Dio dio, {String? baseUrl, ParseErrorLogger? errorLogger})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signIn(
{required String email, String? name, String? callbackURL, String? newUserCallbackURL, String? errorCallbackURL}) → Future< Result< StatusResponse> > -
Sends a magic link to
email. The server delivers the link (email/SMS); the user opens it and the app handles the resulting deep link, then calls verify with thetokenquery parameter. -
toString(
) → String -
A string representation of this object.
inherited
-
verify(
{required String token, String? callbackURL}) → Future< Result< SessionResponse> > -
Exchanges the magic-link
tokenfor a session (sets the session cookie).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited