MultiSessionBetterAuth class abstract
Better Auth multi-session
plugin — manage several signed-in accounts on one device.
- Annotations
-
- @RestApi.new(callAdapter: BetterAuthCallAdapter)
Constructors
- MultiSessionBetterAuth(Dio dio, {String? baseUrl, ParseErrorLogger? errorLogger})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listDeviceSessions(
) → Future< Result< List< >SessionResponse> > - All sessions stored on this device (each with its user).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revoke(
{required String sessionToken}) → Future< Result< StatusResponse> > -
Revokes the device session identified by
sessionToken. -
setActive(
{required String sessionToken}) → Future< Result< SessionResponse> > -
Switches the active session to the one identified by
sessionToken. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited