OrganizationTeam class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- OrganizationTeam({required String id, required String name, required String organizationId, DateTime? createdAt, DateTime? updatedAt})
-
constfactory
-
OrganizationTeam.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $OrganizationTeamCopyWith<
OrganizationTeam> -
Create a copy of OrganizationTeam
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- name → String
-
no setterinherited
- organizationId → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_OrganizationTeam value)) → TResult -
Available on OrganizationTeam, provided by the OrganizationTeamPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_OrganizationTeam value)?) → TResult? -
Available on OrganizationTeam, provided by the OrganizationTeamPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_OrganizationTeam value)?, {required TResult orElse()}) → TResult -
Available on OrganizationTeam, provided by the OrganizationTeamPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String name, String organizationId, DateTime? createdAt, DateTime? updatedAt)?, {required TResult orElse()}) → TResult -
Available on OrganizationTeam, provided by the OrganizationTeamPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this OrganizationTeam to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String name, String organizationId, DateTime? createdAt, DateTime? updatedAt)) → TResult -
Available on OrganizationTeam, provided by the OrganizationTeamPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String name, String organizationId, DateTime? createdAt, DateTime? updatedAt)?) → TResult? -
Available on OrganizationTeam, provided by the OrganizationTeamPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited